@@ -188,7 +188,7 @@ getq(namelist)
 
 	if ((dirp = opendir(SD)) == NULL)
 		return(-1);
-	if (fstat(dirp->dd_fd, &stbuf) < 0)
+	if (fstat(dirfd(dirp), &stbuf) < 0)
 		goto errdone;
 
 	/*
