@@ -33,7 +33,7 @@
 
 #ifndef lint
 /*static char sccsid[] = "from: @(#)cmds.c	5.7 (Berkeley) 6/1/90";*/
-static char rcsid[] = "$Id: cmds.c,v 1.3 1999/02/16 03:45:31 notting Exp $";
+static char rcsid[] = "$Id: cmds.c,v 1.3 1993/12/08 00:50:06 jtc Exp $";
 #endif /* not lint */
 
 /*
@@ -63,7 +63,7 @@ xabort(argc, argv)
 		while (getprent(line) > 0) {
 			cp1 = prbuf;
 			cp2 = line;
-			while ((c = *cp2++) && c != '|' && c != ':' && cp1 - prbuf < sizeof(prbuf))
+			while ((c = *cp2++) && c != '|' && c != ':')
 				*cp1++ = c;
 			*cp1 = '\0';
 			abortpr(1);
@@ -94,7 +94,7 @@ abortpr(dis)
 		SD = _PATH_DEFSPOOL;
 	if ((LO = pgetstr("lo", &bp)) == NULL)
 		LO = DEFLOCK;
-	(void) snprintf(line, sizeof(line), "%s/%s", SD, LO);
+	(void) sprintf(line, "%s/%s", SD, LO);
 	printf("%s:\n", printer);
 
 	/*
@@ -154,7 +154,7 @@ upstat(msg)
 	bp = pbuf;
 	if ((ST = pgetstr("st", &bp)) == NULL)
 		ST = DEFSTAT;
-	(void) snprintf(statfile, sizeof(statfile), "%s/%s", SD, ST);
+	(void) sprintf(statfile, "%s/%s", SD, ST);
 	umask(0);
 	fd = open(statfile, O_WRONLY|O_CREAT, 0664);
 	if (fd < 0 || flock(fd, LOCK_EX) < 0) {
@@ -188,7 +188,7 @@ clean(argc, argv)
 		while (getprent(line) > 0) {
 			cp1 = prbuf;
 			cp2 = line;
-			while ((c = *cp2++) && c != '|' && c != ':' && cp1 - prbuf < sizeof(prbuf))
+			while ((c = *cp2++) && c != '|' && c != ':')
 				*cp1++ = c;
 			*cp1 = '\0';
 			cleanpr();
@@ -255,7 +255,7 @@ cleanpr()
 		SD = _PATH_DEFSPOOL;
 	printf("%s:\n", printer);
 
-	for (lp = line, cp = SD; (lp-line)<sizeof(line) && (*lp++ = *cp++); )
+	for (lp = line, cp = SD; *lp++ = *cp++; )
 		;
 	lp[-1] = '/';
 
@@ -279,8 +279,7 @@ cleanpr()
 				n++;
 			}
 			if (n == 0) {
-				strncpy(lp, cp, sizeof(line)-strlen(line)-1);
-				line[sizeof(line)-1] = '\0';
+				strcpy(lp, cp);
 				unlinkf(line);
 			}
 		} else {
@@ -289,8 +288,7 @@ cleanpr()
 			 * been skipped above) or a tf file (which can always
 			 * be removed).
 			 */
-			strncpy(lp, cp, sizeof(line)-strlen(line)-1);
-			line[sizeof(line)-1] = '\0';
+			strcpy(lp, cp);
 			unlinkf(line);
 		}
      	} while (++i < nitems);
@@ -324,7 +322,7 @@ enable(argc, argv)
 		while (getprent(line) > 0) {
 			cp1 = prbuf;
 			cp2 = line;
-			while ((c = *cp2++) && c != '|' && c != ':' && cp1-prbuf < sizeof(prbuf))
+			while ((c = *cp2++) && c != '|' && c != ':')
 				*cp1++ = c;
 			*cp1 = '\0';
 			enablepr();
@@ -353,7 +351,7 @@ enablepr()
 		SD = _PATH_DEFSPOOL;
 	if ((LO = pgetstr("lo", &bp)) == NULL)
 		LO = DEFLOCK;
-	(void) snprintf(line, sizeof(line), "%s/%s", SD, LO);
+	(void) sprintf(line, "%s/%s", SD, LO);
 	printf("%s:\n", printer);
 
 	/*
@@ -386,7 +384,7 @@ disable(argc, argv)
 		while (getprent(line) > 0) {
 			cp1 = prbuf;
 			cp2 = line;
-			while ((c = *cp2++) && c != '|' && c != ':' && cp1-prbuf < sizeof(prbuf))
+			while ((c = *cp2++) && c != '|' && c != ':')
 				*cp1++ = c;
 			*cp1 = '\0';
 			disablepr();
@@ -416,7 +414,7 @@ disablepr()
 		SD = _PATH_DEFSPOOL;
 	if ((LO = pgetstr("lo", &bp)) == NULL)
 		LO = DEFLOCK;
-	(void) snprintf(line, sizeof(line), "%s/%s", SD, LO);
+	(void) sprintf(line, "%s/%s", SD, LO);
 	printf("%s:\n", printer);
 	/*
 	 * Turn on the group execute bit of the lock file to disable queuing.
@@ -458,7 +456,7 @@ down(argc, argv)
 		while (getprent(line) > 0) {
 			cp1 = prbuf;
 			cp2 = line;
-			while ((c = *cp2++) && c != '|' && c != ':' && cp1-prbuf < sizeof(prbuf))
+			while ((c = *cp2++) && c != '|' && c != ':')
 				*cp1++ = c;
 			*cp1 = '\0';
 			putmsg(argc - 2, argv + 2);
@@ -496,7 +494,7 @@ putmsg(argc, argv)
 	 * Turn on the group execute bit of the lock file to disable queuing and
 	 * turn on the owner execute bit of the lock file to disable printing.
 	 */
-	(void) snprintf(line, sizeof(line), "%s/%s", SD, LO);
+	(void) sprintf(line, "%s/%s", SD, LO);
 	if (stat(line, &stbuf) >= 0) {
 		if (chmod(line, (stbuf.st_mode & 0777) | 0110) < 0)
 			printf("\tcannot disable queuing\n");
@@ -515,7 +513,7 @@ putmsg(argc, argv)
 	/*
 	 * Write the message into the status file.
 	 */
-	(void) snprintf(line, sizeof(line), "%s/%s", SD, ST);
+	(void) sprintf(line, "%s/%s", SD, ST);
 	fd = open(line, O_WRONLY|O_CREAT, 0664);
 	if (fd < 0 || flock(fd, LOCK_EX) < 0) {
 		printf("\tcannot create status file\n");
@@ -530,7 +528,7 @@ putmsg(argc, argv)
 	cp1 = buf;
 	while (--argc >= 0) {
 		cp2 = *argv++;
-		while ((cp1-buf) < sizeof(buf) && (*cp1++ = *cp2++))
+		while (*cp1++ = *cp2++)
 			;
 		cp1[-1] = ' ';
 	}
@@ -568,7 +566,7 @@ restart(argc, argv)
 		while (getprent(line) > 0) {
 			cp1 = prbuf;
 			cp2 = line;
-			while ((c = *cp2++) && c != '|' && c != ':' && cp1-prbuf < sizeof(prbuf))
+			while ((c = *cp2++) && c != '|' && c != ':')
 				*cp1++ = c;
 			*cp1 = '\0';
 			abortpr(0);
@@ -609,7 +607,7 @@ start(argc, argv)
 		while (getprent(line) > 0) {
 			cp1 = prbuf;
 			cp2 = line;
-			while ((c = *cp2++) && c != '|' && c != ':' && cp1-prbuf < sizeof(prbuf))
+			while ((c = *cp2++) && c != '|' && c != ':')
 				*cp1++ = c;
 			*cp1 = '\0';
 			startpr(1);
@@ -638,7 +636,7 @@ startpr(enable)
 		SD = _PATH_DEFSPOOL;
 	if ((LO = pgetstr("lo", &bp)) == NULL)
 		LO = DEFLOCK;
-	(void) snprintf(line, sizeof(line), "%s/%s", SD, LO);
+	(void) sprintf(line, "%s/%s", SD, LO);
 	printf("%s:\n", printer);
 
 	/*
@@ -671,7 +669,7 @@ status(argc, argv)
 		while (getprent(line) > 0) {
 			cp1 = prbuf;
 			cp2 = line;
-			while ((c = *cp2++) && c != '|' && c != ':' && cp1-prbuf < sizeof(prbuf))
+			while ((c = *cp2++) && c != '|' && c != ':')
 				*cp1++ = c;
 			*cp1 = '\0';
 			prstat();
@@ -709,7 +707,7 @@ prstat()
 	if ((ST = pgetstr("st", &bp)) == NULL)
 		ST = DEFSTAT;
 	printf("%s:\n", printer);
-	(void) snprintf(line, sizeof(line), "%s/%s", SD, LO);
+	(void) sprintf(line, "%s/%s", SD, LO);
 	if (stat(line, &stbuf) >= 0) {
 		printf("\tqueuing is %s\n",
 			(stbuf.st_mode & 010) ? "disabled" : "enabled");
@@ -743,7 +741,7 @@ prstat()
 	}
 	(void) close(fd);
 	putchar('\t');
-	(void) snprintf(line, sizeof(line), "%s/%s", SD, ST);
+	(void) sprintf(line, "%s/%s", SD, ST);
 	fd = open(line, O_RDONLY);
 	if (fd >= 0) {
 		(void) flock(fd, LOCK_SH);
@@ -773,7 +771,7 @@ stop(argc, argv)
 		while (getprent(line) > 0) {
 			cp1 = prbuf;
 			cp2 = line;
-			while ((c = *cp2++) && c != '|' && c != ':' && cp1-prbuf < sizeof(prbuf))
+			while ((c = *cp2++) && c != '|' && c != ':')
 				*cp1++ = c;
 			*cp1 = '\0';
 			stoppr();
@@ -803,7 +801,7 @@ stoppr()
 		SD = _PATH_DEFSPOOL;
 	if ((LO = pgetstr("lo", &bp)) == NULL)
 		LO = DEFLOCK;
-	(void) snprintf(line, sizeof(line), "%s/%s", SD, LO);
+	(void) sprintf(line, "%s/%s", SD, LO);
 	printf("%s:\n", printer);
 
 	/*
@@ -998,7 +996,7 @@ up(argc, argv)
 		while (getprent(line) > 0) {
 			cp1 = prbuf;
 			cp2 = line;
-			while ((c = *cp2++) && c != '|' && c != ':' && cp1-prbuf < sizeof(prbuf))
+			while ((c = *cp2++) && c != '|' && c != ':')
 				*cp1++ = c;
 			*cp1 = '\0';
 			startpr(2);
