@@ -37,6 +37,11 @@ char copyright[] =
  All rights reserved.\n";
 #endif /* not lint */
 
+#ifndef lint
+/*static char sccsid[] = "from: @(#)lpd.c	5.12 (Berkeley) 3/7/91";*/
+static char rcsid[] = "$Id: lpd.c,v 1.3 1993/11/10 04:36:34 cgd Exp $";
+#endif /* not lint */
+
 /*
  * lpd -- line printer daemon.
  *
@@ -84,7 +89,6 @@ main(argc, argv)
 	int omask, lfd;
 
 	gethostname(host, sizeof(host));
-	host[MAXHOSTNAMELEN-1]='\0';
 	name = argv[0];
 
 	while (--argc > 0) {
@@ -104,10 +108,6 @@ main(argc, argv)
 	/*
 	 * Set up standard environment by detaching from the parent.
 	 */
-	unsetenv("BASH_ENV");
-	unsetenv("ENV");
-	/* Get rid of any of root's supplementary groups. */
-	setgroups(0,NULL);
 	daemon(0, 0);
 #endif
 
@@ -128,7 +128,7 @@ main(argc, argv)
 	/*
 	 * write process id for others to know
 	 */
-	snprintf(line, BUFSIZ, "%u\n", getpid());
+	sprintf(line, "%u\n", getpid());
 	f = strlen(line);
 	if (write(lfd, line, f) != f) {
 		syslog(LOG_ERR, "%s: %m", _PATH_MASTERLOCK);
@@ -147,7 +147,6 @@ main(argc, argv)
 	}
 #define	mask(s)	(1 << ((s) - 1))
 	omask = sigblock(mask(SIGHUP)|mask(SIGINT)|mask(SIGQUIT)|mask(SIGTERM));
-	umask(07);
 	signal(SIGHUP, mcleanup);
 	signal(SIGINT, mcleanup);
 	signal(SIGQUIT, mcleanup);
@@ -160,7 +159,6 @@ main(argc, argv)
 		syslog(LOG_ERR, "ubind: %m");
 		exit(1);
 	}
-	chmod(_PATH_SOCKETNAME, 0600);	/* we called umask(0) above... */
 	sigsetmask(omask);
 	defreadfds = 1 << funix;
 	listen(funix, 5);
@@ -264,8 +262,8 @@ int	requ[MAXREQUESTS];	/* job number of spool entries */
 int	requests;		/* # of spool requests */
 char	*person;		/* name of person doing lprm */
 
-char	fromb[MAXHOSTNAMELEN];		/* buffer for client's machine name */
-char	cbuf[BUFSIZ];		/* command line buffer */
+char	fromb[32];	/* buffer for client's machine name */
+char	cbuf[BUFSIZ];	/* command line buffer */
 char	*cmdnames[] = {
 	"null",
 	"printjob",
@@ -280,11 +278,6 @@ doit()
 	register char *cp;
 	register int n;
 
-#ifdef MSF_DEBUG	
-	int doh=0;
-	while(!doh);
-#endif	
-	
 	for (;;) {
 		cp = cbuf;
 		do {
@@ -411,8 +404,6 @@ startup()
 		if (!pid) {
 			endprent();
 			printjob();
-		} else if (pid > 0) {
-		        waitpid(pid, NULL, 0); /* wait for it to do its job */
 		}
 	}
 }
@@ -428,13 +419,13 @@ chkhost(f)
 	register struct hostent *hp;
 	register FILE *hostf;
 	register char *cp, *sp;
+	char ahost[50];
 	int first = 1;
+	extern char *inet_ntoa();
 	int baselen = -1;
-	int good = 0;
 
 	f->sin_port = ntohs(f->sin_port);
-	if (f->sin_family != AF_INET || f->sin_port >= IPPORT_RESERVED ||
-	    f->sin_port < IPPORT_RESERVED/2)
+	if (f->sin_family != AF_INET || f->sin_port >= IPPORT_RESERVED)
 		fatal("Malformed from address");
 	hp = gethostbyaddr((char *)&f->sin_addr,
 	    sizeof(struct in_addr), f->sin_family);
@@ -442,49 +433,30 @@ chkhost(f)
 		fatal("Host name for your address (%s) unknown",
 			inet_ntoa(f->sin_addr));
 
-	strncpy(fromb, hp->h_name, sizeof(fromb)-1);
-	fromb[sizeof(fromb)-1] = '\0';
+	strcpy(fromb, hp->h_name);
 	from = fromb;
-	
-	/* Check for spoof */
-	hp = gethostbyname(fromb);
-	if (!hp)
-		fatal("Host name for your address (%s) unknown",
-		      inet_ntoa(f->sin_addr));
-	for (; good == 0 && hp->h_addr_list[0] != NULL; hp->h_addr_list++) {
-		if (!memcmp(hp->h_addr_list[0], (caddr_t)&f->sin_addr,
-			    sizeof(f->sin_addr)))
-		  good = 1;
-	}
-	if (good == 0)
-		fatal("address for your hostname (%s) not matched",
-		      inet_ntoa(f->sin_addr));
-	
 	if (!strcmp(from, host))
 		return;
 
-	for (sp = fromb; *sp && cp < (fromb + sizeof(fromb) - 1); sp++) {
+	sp = fromb;
+	cp = ahost;
+	while (*sp) {
 		if (*sp == '.') {
 			if (baselen == -1)
 				baselen = sp - fromb;
-		} else if (isupper(*sp)) {
-			*sp = tolower(*sp);
+			*cp++ = *sp++;
+		} else {
+			*cp++ = isupper(*sp) ? tolower(*sp++) : *sp++;
 		}
 	}
+	*cp = '\0';
 	hostf = fopen(_PATH_HOSTSEQUIV, "r");
 again:
 	if (hostf) {
-#if __GNU_LIBRARY__ - 0 >= 6
-		if (!__ivaliduser(hostf, f->sin_addr.s_addr, DUMMY, DUMMY)) {
+		if (!_validuser(hostf, ahost, DUMMY, DUMMY, baselen)) {
 			(void) fclose(hostf);
 			return;
 		}
-#else
-		if (!_validuser(hostf, fromb, DUMMY, DUMMY, baselen)) {
-			(void) fclose(hostf);
-			return;
-		}
-#endif
 		(void) fclose(hostf);
 	}
 	if (first == 1) {
